@@ -148,3 +148,16 @@ test_that(desc="get_pxweb_data()",{
   }
 })
 
+test_that(desc="Test warnings",{  
+  
+  skip_on_cran()
+  
+  expect_that({
+    test_url <- "http://api.scb.se/OV0104/v1/doris/sv/ssd/TK/TK1001/TK1001S/SnabbStatTK1001"
+    test_dims <- list("ContentsCode" = c("TK1001AE"), "Tid" = c("2014M02"))
+    test_data <- 
+      get_pxweb_data(url = test_url,
+                     dims = test_dims,
+                     clean = TRUE)}, 
+    not(gives_warning()))
+})
\ No newline at end of file
